import { IInputAreaModel } from 'jupyter-js-input-area';
import { IOutputAreaModel } from 'jupyter-js-output-area';
import { IObservableList } from 'phosphor-observablelist';
import { IChangedArgs, Property } from 'phosphor-properties';
import { ISignal, Signal } from 'phosphor-signaling';
/**
 * An enum which describes the type of cell.
 */
export declare enum CellType {
    /**
     * The cell contains code input.
     */
    Code = 0,
    /**
     * The cell contains markdown.
     */
    Markdown = 1,
    /**
     * The cell contains raw text.
     */
    Raw = 2,
}
/**
 * An object which is serializable.
 */
export interface ISerializable {
    toJSON(): any;
    fromJSON(data: any): void;
}
/**
 * The definition of a model object for a base cell.
 */
export interface IBaseCellModel {
    /**
     * The type of cell.
     */
    type: CellType;
    /**
     * Tags applied to the cell.
     */
    tags?: IObservableList<string>;
    /**
     * A signal emitted when state of the cell changes.
     */
    stateChanged: ISignal<IBaseCellModel, IChangedArgs<any>>;
    /**
     * Get namespaced metadata about the cell.
     */
    /**
     * The input area of the cell.
     */
    input: IInputAreaModel;
}
/**
 * The definition of a code cell.
 */
export interface ICodeCellModel extends IBaseCellModel {
    output: IOutputAreaModel;
}
/**
 * The definition of a raw cell.
 */
export interface IRawCellModel extends IBaseCellModel {
    /**
     * The raw cell format.
     */
    format?: string;
}
/**
 * The definition of a markdown cell.
 */
export interface IMarkdownCellModel extends IBaseCellModel {
    /**
     * Whether a cell is rendered.
     */
    rendered: boolean;
}
/**
 * A model consisting of any valid cell type.
 */
export declare type ICellModel = (IRawCellModel | IMarkdownCellModel | ICodeCellModel);
/**
 * An implemention of the base cell Model.
 */
export declare class BaseCellModel implements IBaseCellModel {
    /**
     * A signal emitted when the state of the model changes.
     *
     * **See also:** [[stateChanged]]
     */
    static stateChangedSignal: Signal<IBaseCellModel, IChangedArgs<any>>;
    /**
     * A signal emitted when the state of the model changes.
     *
     * #### Notes
     * This is a pure delegate to the [[stateChangedSignal]].
     */
    stateChanged: ISignal<IBaseCellModel, IChangedArgs<any>>;
    /**
     * A property descriptor for the input area model.
     *
     * **See also:** [[input]]
     */
    static inputProperty: Property<IBaseCellModel, IInputAreaModel>;
    /**
     * Get the input area model.
     *
     * #### Notes
     * This is a pure delegate to the [[inputProperty]].
     */
    /**
     * Set the input area model.
     *
     * #### Notes
     * This is a pure delegate to the [[inputProperty]].
     */
    input: IInputAreaModel;
    /**
     * The type of cell.
     */
    type: CellType;
}
/**
 * An implementation of a code cell Model.
 */
export declare class CodeCellModel extends BaseCellModel implements ICodeCellModel {
    /**
    * A property descriptor holding the output area model.
    *
    * TODO: Do we need this execute signal?
    * **See also:** [[output]]
    */
    static outputProperty: Property<CodeCellModel, IOutputAreaModel>;
    /**
     * Get the output area model.
     *
     * #### Notes
     * This is a pure delegate to the [[outputProperty]].
     */
    /**
     * Set the output area model.
     *
     * #### Notes
     * This is a pure delegate to the [[outputProperty]].
     */
    output: IOutputAreaModel;
    type: CellType;
}
/**
 * An implementation of a Markdown cell Model.
 */
export declare class MarkdownCellModel extends BaseCellModel implements IMarkdownCellModel {
    /**
     * A property descriptor which determines whether the input area should be rendered.
     *
     * **See also:** [[rendered]]
     */
    static renderedProperty: Property<MarkdownCellModel, boolean>;
    /**
     * Get whether we should display a rendered representation.
     *
     * #### Notes
     * This is a pure delegate to the [[renderedProperty]].
     */
    /**
     * Get whether we should display a rendered representation.
     *
     * #### Notes
     * This is a pure delegate to the [[renderedProperty]].
     */
    rendered: boolean;
    type: CellType;
}
/**
  * A type guard for testing if a cell is a markdown cell.
  */
export declare function isMarkdownCell(m: ICellModel): m is IMarkdownCellModel;
/**
  * A type guard for testing if a cell is a code cell.
  */
export declare function isCodeCell(m: ICellModel): m is ICodeCellModel;
/**
  * A type guard for testing if a cell is a raw cell.
  */
export declare function isRawCell(m: ICellModel): m is IRawCellModel;
