// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
'use strict';
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var phosphor_properties_1 = require('phosphor-properties');
var phosphor_signaling_1 = require('phosphor-signaling');
/**
 * An enum which describes the type of cell.
 */
(function (CellType) {
    /**
     * The cell contains code input.
     */
    CellType[CellType["Code"] = 0] = "Code";
    /**
     * The cell contains markdown.
     */
    CellType[CellType["Markdown"] = 1] = "Markdown";
    /**
     * The cell contains raw text.
     */
    CellType[CellType["Raw"] = 2] = "Raw";
})(exports.CellType || (exports.CellType = {}));
var CellType = exports.CellType;
/**
 * An implemention of the base cell Model.
 */
var BaseCellModel = (function () {
    function BaseCellModel() {
    }
    Object.defineProperty(BaseCellModel.prototype, "stateChanged", {
        /**
         * A signal emitted when the state of the model changes.
         *
         * #### Notes
         * This is a pure delegate to the [[stateChangedSignal]].
         */
        get: function () {
            return BaseCellModel.stateChangedSignal.bind(this);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseCellModel.prototype, "input", {
        /**
         * Get the input area model.
         *
         * #### Notes
         * This is a pure delegate to the [[inputProperty]].
         */
        get: function () {
            return BaseCellModel.inputProperty.get(this);
        },
        /**
         * Set the input area model.
         *
         * #### Notes
         * This is a pure delegate to the [[inputProperty]].
         */
        set: function (value) {
            BaseCellModel.inputProperty.set(this, value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * A signal emitted when the state of the model changes.
     *
     * **See also:** [[stateChanged]]
     */
    BaseCellModel.stateChangedSignal = new phosphor_signaling_1.Signal();
    /**
     * A property descriptor for the input area model.
     *
     * **See also:** [[input]]
     */
    BaseCellModel.inputProperty = new phosphor_properties_1.Property({
        name: 'input',
        notify: BaseCellModel.stateChangedSignal,
    });
    return BaseCellModel;
})();
exports.BaseCellModel = BaseCellModel;
/**
 * An implementation of a code cell Model.
 */
var CodeCellModel = (function (_super) {
    __extends(CodeCellModel, _super);
    function CodeCellModel() {
        _super.apply(this, arguments);
        this.type = CellType.Code;
    }
    Object.defineProperty(CodeCellModel.prototype, "output", {
        /**
         * Get the output area model.
         *
         * #### Notes
         * This is a pure delegate to the [[outputProperty]].
         */
        get: function () {
            return CodeCellModel.outputProperty.get(this);
        },
        /**
         * Set the output area model.
         *
         * #### Notes
         * This is a pure delegate to the [[outputProperty]].
         */
        set: function (value) {
            CodeCellModel.outputProperty.set(this, value);
        },
        enumerable: true,
        configurable: true
    });
    /**
    * A property descriptor holding the output area model.
    *
    * TODO: Do we need this execute signal?
    * **See also:** [[output]]
    */
    CodeCellModel.outputProperty = new phosphor_properties_1.Property({
        name: 'output',
        notify: CodeCellModel.stateChangedSignal,
    });
    return CodeCellModel;
})(BaseCellModel);
exports.CodeCellModel = CodeCellModel;
/**
 * An implementation of a Markdown cell Model.
 */
var MarkdownCellModel = (function (_super) {
    __extends(MarkdownCellModel, _super);
    function MarkdownCellModel() {
        _super.apply(this, arguments);
        this.type = CellType.Markdown;
    }
    Object.defineProperty(MarkdownCellModel.prototype, "rendered", {
        /**
         * Get whether we should display a rendered representation.
         *
         * #### Notes
         * This is a pure delegate to the [[renderedProperty]].
         */
        get: function () {
            return MarkdownCellModel.renderedProperty.get(this);
        },
        /**
         * Get whether we should display a rendered representation.
         *
         * #### Notes
         * This is a pure delegate to the [[renderedProperty]].
         */
        set: function (value) {
            MarkdownCellModel.renderedProperty.set(this, value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * A property descriptor which determines whether the input area should be rendered.
     *
     * **See also:** [[rendered]]
     */
    MarkdownCellModel.renderedProperty = new phosphor_properties_1.Property({
        name: 'rendered',
        notify: MarkdownCellModel.stateChangedSignal,
    });
    return MarkdownCellModel;
})(BaseCellModel);
exports.MarkdownCellModel = MarkdownCellModel;
/**
  * A type guard for testing if a cell is a markdown cell.
  */
function isMarkdownCell(m) {
    return (m.type === CellType.Markdown);
}
exports.isMarkdownCell = isMarkdownCell;
/**
  * A type guard for testing if a cell is a code cell.
  */
function isCodeCell(m) {
    return (m.type === CellType.Code);
}
exports.isCodeCell = isCodeCell;
/**
  * A type guard for testing if a cell is a raw cell.
  */
function isRawCell(m) {
    return (m.type === CellType.Raw);
}
exports.isRawCell = isRawCell;
//# sourceMappingURL=model.js.map