// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
'use strict';
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var phosphor_widget_1 = require('phosphor-widget');
var phosphor_panel_1 = require('phosphor-panel');
var jupyter_js_input_area_1 = require('jupyter-js-input-area');
var jupyter_js_output_area_1 = require('jupyter-js-output-area');
var marked = require('marked');
/**
 * A base cell widget.
 */
var CellWidget = (function (_super) {
    __extends(CellWidget, _super);
    function CellWidget() {
        _super.call(this);
        // we make the cell focusable by setting the tabIndex
        this.node.tabIndex = -1;
        this.layout = new phosphor_panel_1.PanelLayout();
    }
    return CellWidget;
})(phosphor_widget_1.Widget);
exports.CellWidget = CellWidget;
/**
 * A widget for a code cell.
 */
var CodeCellWidget = (function (_super) {
    __extends(CodeCellWidget, _super);
    /**
     * Construct a code cell widget.
     */
    function CodeCellWidget(model) {
        _super.call(this);
        this.addClass('jp-Cell');
        this.addClass('jp-CodeCell');
        this._model = model;
        this.input = new jupyter_js_input_area_1.InputAreaWidget(model.input);
        this.output = new jupyter_js_output_area_1.OutputAreaWidget(model.output);
        this.layout.addChild(this.input);
        this.layout.addChild(this.output);
        model.stateChanged.connect(this.modelStateChanged, this);
    }
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    CodeCellWidget.prototype.updateInputArea = function (input) {
        this.input.dispose(); // removes from children
        this.input = new jupyter_js_input_area_1.InputAreaWidget(input);
        this.layout.insertChild(0, this.input);
    };
    /**
     * Update the output area, creating a new output area
     * widget and detaching the old one.
     */
    CodeCellWidget.prototype.updateOutputArea = function (output) {
        this.output.dispose();
        this.output = new jupyter_js_output_area_1.OutputAreaWidget(output);
        this.layout.insertChild(1, this.output);
    };
    /**
     * Change handler for model updates.
     */
    CodeCellWidget.prototype.modelStateChanged = function (sender, args) {
        switch (args.name) {
            case 'input':
                this.updateInputArea(args.newValue);
                break;
            case 'output':
                this.updateOutputArea(args.newValue);
                break;
        }
    };
    return CodeCellWidget;
})(CellWidget);
exports.CodeCellWidget = CodeCellWidget;
/**
 * A widget for a Markdown cell.
 *
 * #### Notes
 * Things get complicated if we want the rendered text to update
 * any time the text changes, the text editor model changes,
 * or the input area model changes.  We don't support automatically
 * updating the rendered text in all of these cases.
 */
var MarkdownCellWidget = (function (_super) {
    __extends(MarkdownCellWidget, _super);
    /**
     * Construct a Markdown cell widget.
     */
    function MarkdownCellWidget(model) {
        _super.call(this);
        this.addClass('jp-Cell');
        this.addClass('jp-MarkdownCell');
        this._model = model;
        // Insist on the Github-flavored markdown mode
        model.input.textEditor.mimetype = 'text/x-gfm';
        this.input = new jupyter_js_input_area_1.InputAreaWidget(model.input);
        this.rendered = new phosphor_widget_1.Widget();
        if (model.rendered) {
            this.renderInput();
        }
        else {
            this.editInput();
        }
        model.stateChanged.connect(this.modelStateChanged, this);
    }
    /**
     * Process the input and display the rendered Markdown.
     *
     * #### Notes
     * This will remove the input widget.
     * Call [[editInput]] to restore the editor.
     */
    MarkdownCellWidget.prototype.renderInput = function () {
        this.rendered.node.innerHTML = marked(this._model.input.textEditor.text);
        this.input.parent = null;
        this.layout.addChild(this.rendered);
    };
    /**
     * Edit the Markdown source.
     *
     * #### Notes
     * This will remove the rendered widget.
     * Call [[renderInput]] to render the source.
     */
    MarkdownCellWidget.prototype.editInput = function () {
        this.rendered.parent = null;
        this.layout.addChild(this.input);
    };
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    MarkdownCellWidget.prototype.updateInputArea = function (input) {
        this.input.dispose();
        this.input = new jupyter_js_input_area_1.InputAreaWidget(input);
        if (this._model.rendered) {
            this.renderInput();
        }
        else {
            this.editInput();
        }
    };
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    MarkdownCellWidget.prototype.updateRendered = function (rendered) {
        if (rendered) {
            this.renderInput();
        }
        else {
            this.editInput();
        }
    };
    /**
     * Change handler for model updates.
     */
    MarkdownCellWidget.prototype.modelStateChanged = function (sender, args) {
        switch (args.name) {
            case 'input':
                this.updateInputArea(args.newValue);
                break;
            case 'rendered':
                this.updateRendered(args.newValue);
                break;
        }
    };
    return MarkdownCellWidget;
})(CellWidget);
exports.MarkdownCellWidget = MarkdownCellWidget;
//# sourceMappingURL=widget.js.map